@@ -1,6 +1,6 @@
 // ICapturer.cs
 //
-//  Copyright (C) 2008-2009 Andoni Morales Alastruey
+//  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -11,58 +11,83 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
 
 using System;
+using LongoMatch.Video.Common;
+using Gdk;
 
 namespace LongoMatch.Video.Capturer
 {
-	
-	
+
+
 	public interface ICapturer
 	{
-		
-		
-		uint EncodeWidth {
+		event EllpasedTimeHandler EllapsedTime;
+		event ErrorHandler Error;
+		event DeviceChangeHandler DeviceChange;
+
+		uint OutputWidth {
 			get ;
 			set ;
 		}
 
-		uint EncodeHeight {
+		uint OutputHeight {
 			get;
 			set ;
 		}
-		
-		 string OutputFile {
+
+		string OutputFile {
 			get ;
 			set ;
 		}
 
-				
 		uint VideoBitrate {
 			get;
 			set ;
 		}
-		
+
 		uint AudioBitrate {
 			get ;
 			set ;
 		}
-		bool SetVideoEncoder(LongoMatch.Video.Capturer.GccVideoEncoderType type);
-		bool SetAudioEncoder(LongoMatch.Video.Capturer.GccAudioEncoderType type);
-		bool SetVideoMuxer(LongoMatch.Video.Capturer.GccVideoMuxerType type);
-		
+
+		int CurrentTime {
+			get ;
+		}
+
+		Pixbuf CurrentFrame {
+			get;
+		}
+
+		string DeviceID {
+			set;
+			get;
+		}
+
+		bool SetVideoEncoder(VideoEncoderType type);
+
+		bool SetAudioEncoder(AudioEncoderType type);
+
+		bool SetVideoMuxer(VideoMuxerType type);
+
+		bool SetSource(CaptureSourceType type);
+
 		void TogglePause();
-		
+
 		void Start();
-		
+
 		void Stop();
-		
+
 		void Run();
+
+		void Close();
+
+		void Dispose();
 	}
 }
