@@ -1,6 +1,6 @@
 // IFramesCapturer.cs
 //
-//  Copyright (C) 2008-2009 Andoni Morales Alastruey
+//  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -11,10 +11,10 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
 
@@ -23,16 +23,16 @@ using Gdk;
 
 namespace LongoMatch.Video.Utils
 {
-	
-	
+
+
 	public interface IFramesCapturer
 	{
 		bool Open(string mrl);
 		bool SeekTime(long time, bool accurate);
 		void Pause();
 		void Dispose();
-		Pixbuf CurrentFrame{
-			get;
-		}
+		Pixbuf GetCurrentFrame(int outwidth, int outheight);
+		Pixbuf GetCurrentFrame();
+
 	}
 }
