@@ -35,25 +35,16 @@ namespace LongoMatch.Gui.Component
 		public event ClearDrawingHandler ClearDrawing;
 		public event TransparencyChangedHandler TransparencyChanged;
 
-		Gdk.Color normalColor;
-		Gdk.Color activeColor;
-
 		public DrawingToolBox()
 		{
 			this.Build();
-			SetButtonColor(wbutton,"white");
-			SetButtonColor(bbutton,"black");
-			SetButtonColor(rbutton,"red");
-			SetButtonColor(gbutton,"green");
-			SetButtonColor(blbutton,"blue");
-			SetButtonColor(ybutton,"yellow");
 			penbutton.Active = true;
-			rbutton.Active = true;
+			colorbutton.Color = new Color(byte.MaxValue, byte.MinValue, byte.MinValue);/* red */
 		}
 
 		public bool DrawingVisibility {
 			set {
-				if (VisibilityChanged != null)
+				if(VisibilityChanged != null)
 					VisibilityChanged(value);
 			}
 		}
@@ -71,89 +62,67 @@ namespace LongoMatch.Gui.Component
 			}
 		}
 
-		private void SetButtonColor(Button button, string color) {
-
-			string darkColor;
-
-			if (color == "yellow")
-				darkColor = "goldenrod";
-			else if (color == "white")
-				darkColor = "beige";
-			else if (color == "black")
-				darkColor = "black";
-			else
-				darkColor = "dark "+color;
-
-			Gdk.Color.Parse(color,ref normalColor);
-			Gdk.Color.Parse(darkColor,ref activeColor);
-			button.ModifyBg(StateType.Normal,normalColor);
-			button.ModifyBg(StateType.Active,activeColor);
-			button.ModifyBg(StateType.Selected,activeColor);
-			button.ModifyBg(StateType.Prelight,normalColor);
-		}
-
 		protected virtual void OnCombobox1Changed(object sender, System.EventArgs e)
 		{
 			int lineWidth;
-			if (LineWidthChanged != null) {
+			if(LineWidthChanged != null) {
 				lineWidth = Int16.Parse(combobox1.ActiveText.Split(' ')[0]);
 				LineWidthChanged(lineWidth);
 			}
 		}
 
-		protected virtual void OnButtonToggled(object sender, System.EventArgs e)
-		{
-			RadioButton button = sender as RadioButton;
-			if (ColorChanged != null && button.Active)
-				ColorChanged(button.Style.Background(StateType.Normal));
-		}
-
 		protected virtual void OnCirclebuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.CIRCLE);
 		}
 
 		protected virtual void OnRectanglebuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.RECTANGLE);
 		}
 
 		protected virtual void OnLinebuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.LINE);
 		}
 
 		protected virtual void OnCrossbuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.CROSS);
 		}
 
 		protected virtual void OnEraserbuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.ERASER);
 		}
 
 		protected virtual void OnPenbuttonToggled(object sender, System.EventArgs e)
 		{
-			if (DrawToolChanged != null && (sender as RadioButton).Active)
+			if(DrawToolChanged != null && (sender as RadioButton).Active)
 				DrawToolChanged(DrawTool.PEN);
 		}
 
 		protected virtual void OnClearbuttonClicked(object sender, System.EventArgs e)
 		{
-			if (ClearDrawing != null)
+			if(ClearDrawing != null)
 				ClearDrawing();
 		}
 
 		protected virtual void OnSpinbutton1Changed(object sender, System.EventArgs e)
 		{
-			if (TransparencyChanged != null)
+			if(TransparencyChanged != null)
 				TransparencyChanged(spinbutton1.Value/100);
 		}
+
+		protected virtual void OnColorbuttonColorSet(object sender, System.EventArgs e)
+		{
+			if(ColorChanged != null)
+				ColorChanged(colorbutton.Color);
+		}
 	}
 }
