@@ -19,27 +19,29 @@
 //
 
 using System;
+using System.Collections.Generic;
 using Gdk;
 using Gtk;
 using Mono.Unix;
 using LongoMatch.Handlers;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
 
 namespace LongoMatch.Gui.Component
 {
 
-	public delegate void PlayerPropertiesHandler(Player player);
 
 	[System.ComponentModel.Category("LongoMatch")]
 	[System.ComponentModel.ToolboxItem(true)]
 	public class PlayerPropertiesTreeView : Gtk.TreeView
 	{
 		public event PlayerPropertiesHandler PlayerClicked;
-		public event PlayerPropertiesHandler PlayerSelected;
+		public event PlayersPropertiesHandler PlayersSelected;
 
 		public PlayerPropertiesTreeView() {
 
 			RowActivated += OnTreeviewRowActivated;
+			Selection.Changed += OnSelectionChanged;
+			Selection.Mode =  SelectionMode.Multiple;
 
 			Gtk.TreeViewColumn photoColumn = new Gtk.TreeViewColumn();
 			photoColumn.Title = Catalog.GetString("Photo");
@@ -50,17 +52,22 @@ namespace LongoMatch.Gui.Component
 			nameColumn.Title = Catalog.GetString("Name");
 			Gtk.CellRendererText nameCell = new Gtk.CellRendererText();
 			nameColumn.PackStart(nameCell, true);
-			
+
+			Gtk.TreeViewColumn playsColumn = new Gtk.TreeViewColumn();
+			playsColumn.Title = Catalog.GetString("Play this match");
+			Gtk.CellRendererText playCell = new Gtk.CellRendererText();
+			playsColumn.PackStart(playCell, true);
+
 			Gtk.TreeViewColumn birthdayColumn = new Gtk.TreeViewColumn();
 			birthdayColumn.Title = Catalog.GetString("Date of Birth");
 			Gtk.CellRendererText birthdayCell = new Gtk.CellRendererText();
 			birthdayColumn.PackStart(birthdayCell, true);
-			
+
 			Gtk.TreeViewColumn nationColumn = new Gtk.TreeViewColumn();
 			nationColumn.Title = Catalog.GetString("Nationality");
 			Gtk.CellRendererText nationCell = new Gtk.CellRendererText();
 			nationColumn.PackStart(nationCell, true);
-			
+
 			Gtk.TreeViewColumn heightColumn = new Gtk.TreeViewColumn();
 			heightColumn.Title = Catalog.GetString("Height");
 			Gtk.CellRendererText heightCell = new Gtk.CellRendererText();
@@ -70,7 +77,7 @@ namespace LongoMatch.Gui.Component
 			weightColumn.Title = Catalog.GetString("Weight");
 			Gtk.CellRendererText weightCell = new Gtk.CellRendererText();
 			weightColumn.PackStart(weightCell, true);
-			
+
 			Gtk.TreeViewColumn positionColumn = new Gtk.TreeViewColumn();
 			positionColumn.Title = Catalog.GetString("Position");
 			Gtk.CellRendererText positionCell = new Gtk.CellRendererText();
@@ -83,6 +90,7 @@ namespace LongoMatch.Gui.Component
 
 			photoColumn.SetCellDataFunc(photoCell, new Gtk.TreeCellDataFunc(RenderPhoto));
 			nameColumn.SetCellDataFunc(nameCell, new Gtk.TreeCellDataFunc(RenderName));
+			playsColumn.SetCellDataFunc(playCell, new Gtk.TreeCellDataFunc(RenderPlay));
 			nationColumn.SetCellDataFunc(nationCell, new Gtk.TreeCellDataFunc(RenderNationality));
 			positionColumn.SetCellDataFunc(positionCell, new Gtk.TreeCellDataFunc(RenderPosition));
 			numberColumn.SetCellDataFunc(numberCell, new Gtk.TreeCellDataFunc(RenderNumber));
@@ -92,6 +100,7 @@ namespace LongoMatch.Gui.Component
 
 			AppendColumn(photoColumn);
 			AppendColumn(nameColumn);
+			AppendColumn(playsColumn);
 			AppendColumn(numberColumn);
 			AppendColumn(positionColumn);
 			AppendColumn(heightColumn);
@@ -114,6 +123,13 @@ namespace LongoMatch.Gui.Component
 			(cell as Gtk.CellRendererText).Text = player.Name;
 		}
 
+		private void RenderPlay(Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+		{
+			Player player = (Player) model.GetValue(iter, 0);
+
+			(cell as Gtk.CellRendererText).Text = player.Playing ? Catalog.GetString("Yes") : Catalog.GetString("No");
+		}
+
 		private void RenderNationality(Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 		{
 			Player player = (Player) model.GetValue(iter, 0);
@@ -141,14 +157,14 @@ namespace LongoMatch.Gui.Component
 
 			(cell as Gtk.CellRendererText).Text = player.Height.ToString();
 		}
-		
+
 		private void RenderWeight(Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 		{
 			Player player = (Player) model.GetValue(iter, 0);
 
 			(cell as Gtk.CellRendererText).Text = player.Weight.ToString();
 		}
-		
+
 		private void RenderBirthday(Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 		{
 			Player player = (Player) model.GetValue(iter, 0);
@@ -156,12 +172,28 @@ namespace LongoMatch.Gui.Component
 			(cell as Gtk.CellRendererText).Text = player.Birthday.ToShortDateString();
 		}
 
+		protected virtual void OnSelectionChanged(object o, System.EventArgs e) {
+			TreeIter iter;
+			List<Player> list;
+			TreePath[] pathArray;
+
+			list = new List<Player>();
+			pathArray = Selection.GetSelectedRows();
+
+			for(int i=0; i< pathArray.Length; i++) {
+				Model.GetIterFromString(out iter, pathArray[i].ToString());
+				list.Add((Player) Model.GetValue(iter, 0));
+			}
+			if(PlayersSelected != null)
+				PlayersSelected(list);
+		}
+
 		protected virtual void OnTreeviewRowActivated(object o, Gtk.RowActivatedArgs args)
 		{
 			Gtk.TreeIter iter;
 			Model.GetIter(out iter, args.Path);
 			Player player = (Player) Model.GetValue(iter, 0);
-			if (PlayerClicked != null)
+			if(PlayerClicked != null)
 				PlayerClicked(player);
 		}
 	}
