@@ -12,62 +12,59 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
-using System;
 using System.Collections.Generic;
-using Gtk;
 using Gdk;
-using LongoMatch.DB;
-using LongoMatch.TimeNodes;
+using Gtk;
+using LongoMatch.Store;
+using LongoMatch.Store.Templates;
 
 namespace LongoMatch.Handlers
 {
-	
-	
+
+
 	public class HotKeysManager
 	{
-		private Dictionary<HotKey,int> dic;
+		private Dictionary<HotKey, Category> dic;
 		public event NewMarkEventHandler newMarkEvent;
-		
+
 		public HotKeysManager()
 		{
-			dic = new Dictionary<HotKey,int>();		
-		}		
-		
-		public Sections Sections{
-			set{
+			dic = new Dictionary<HotKey,Category>();
+		}
+
+		// Set the active Hotkeys for the current project
+		public Categories Categories {
+			set {
 				dic.Clear();
-				if (value == null)
+				if(value == null)
 					return;
-				for (int i=0;i<value.Count;i++){
-					if (value.GetHotKey(i).Defined &&
-					    !dic.ContainsKey(value.GetHotKey(i)))	
-						dic.Add(value.GetHotKey(i),i);					
+				foreach(Category cat in value) {
+					if(cat.HotKey.Defined &&
+					                !dic.ContainsKey(cat.HotKey))
+						dic.Add(cat.HotKey, cat);
 				}
 			}
-		}		
-		
-		public void KeyListener(object sender, KeyPressEventArgs args){
-			if ((args.Event.State  & (ModifierType.Mod1Mask | ModifierType.Mod5Mask | ModifierType.ShiftMask)) != 0){
-				int section=-1;
-				HotKey hotkey = new HotKey();
-				hotkey.Key=args.Event.Key;
-				hotkey.Modifier=args.Event.State & (ModifierType.Mod1Mask | ModifierType.Mod5Mask | ModifierType.ShiftMask);
-				if (dic.TryGetValue(hotkey,out section)){					
-					if (newMarkEvent != null){
-						newMarkEvent(section);
-					}
+		}
+
+		// Listen to key press events and fire a newMarkEvent event if the key combination
+		// is associated to a Category
+		public void KeyListener(object sender, KeyPressEventArgs args) {
+			Category cat = null;
+			HotKey hotkey = new HotKey();
+
+			hotkey.Key=args.Event.Key;
+			hotkey.Modifier=args.Event.State & (ModifierType.Mod1Mask | ModifierType.Mod5Mask | ModifierType.ShiftMask);
+			if(dic.TryGetValue(hotkey, out cat)) {
+				if(newMarkEvent != null) {
+					newMarkEvent(cat);
 				}
 			}
 		}
-		
-		
-		
-		
 	}
 }
