@@ -1,6 +1,6 @@
 // IPlayList.cs
 //
-//  Copyright (C) 2008-2009 Andoni Morales Alastruey
+//  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -11,34 +11,46 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
 
 using System;
 using System.Collections;
 using Gtk;
-using LongoMatch.TimeNodes;
+using LongoMatch.Store;
+
+namespace LongoMatch.Playlist {
 
-namespace LongoMatch.Playlist{
-		
 	public interface IPlayList:IEnumerable
 	{
-		int Count {get;}
-		void Load (string path);
-		void Save (string path);
-		void Add(PlayListTimeNode plNode);
-		void Remove (PlayListTimeNode plNode);
-		PlayListTimeNode Next();
-		PlayListTimeNode Prev();
-		PlayListTimeNode Select(int index);	
-		int GetCurrentIndex();		
+		int Count {
+			get;
+		}
+
+		void Save(string path);
+
+		void Add(PlayListPlay play);
+
+		bool Remove(PlayListPlay play);
+
+		PlayListPlay Next();
+
+		PlayListPlay Prev();
+
+		PlayListPlay Select(int index);
+
+		int GetCurrentIndex();
+
 		bool HasNext();
+
 		bool HasPrev();
+
 		ListStore GetModel();
+
 		IPlayList Copy();
 	}
 }
